"""SatNOGS Config module main function"""
import sys

import satnogsconfig

if __name__ == '__main__':
    sys.exit(satnogsconfig.main())
